@@ -92,7 +92,7 @@ class IntegrationWebhookContext(IntegrationWebhookRoutes):
     def _notice_hook_route(self, url_path: str, method: str,
                            label: 'Optional[str]') -> 'WebhookRouteStatus':
 
-        LOG.debug('Registered hook (label: %s): %s %r', label, method, url_path)
+        LOG.info('Registered hook (label: %s): %s %r', label, method, url_path)
 
         route_status = \
             WebhookRouteStatus(
